@@ -385,13 +385,18 @@ s_loglgst <- function(x, par){
 
 get_etas <- function(fit, newdata = NULL, reg_pars = NULL){
   if(fit$par == 'non-parametric'){ans <- 1; names(ans) <- 'baseline'; return(ans)}
-	if(is.null(newdata)){ans <- exp(-fit$baseOffset); names(ans) <- 'baseline'; return(ans)}
+  if(is.null(reg_pars)){ reg_pars <- default_reg_pars(fit) }
+  if(!is.matrix(reg_pars)) reg_pars <- matrix(reg_pars, ncol = length(default_reg_pars(fit)))
+  if(is.null(newdata)){
+    ans <- 1
+	  names(ans) <- 'baseline'
+	  return(ans)
+	}
 	if(identical(newdata, 'midValues')){
   	ans <- 1
   	names(ans) <- 'Mean Covariate Values'
   	return(ans)
 	}
-  if(is.null(reg_pars)){ reg_pars <- default_reg_pars(fit) }
   if(identical(rownames(newdata), NULL) ) {rownames(newdata) <- as.character(1:icr_nrow(newdata))}
 	grpNames <- rownames(newdata)
 	reducFormula <- fit$formula
@@ -404,7 +409,10 @@ get_etas <- function(fit, newdata = NULL, reg_pars = NULL){
 	    ans <- rep(1, length(reg_pars))
 	  return(ans)
 	}
-	log_etas <- as.numeric( new_x %*% reg_pars - fit$baseOffset) 	
+	covarOffset <- fit$covarOffset
+#	new_x <- new_x - covarOffset
+	new_x <- subtractOffset(new_x, covarOffset)
+	log_etas <- as.numeric( new_x %*% t(reg_pars) ) 	
 	etas <- exp(log_etas)
 	if(length(grpNames) == length(etas)){ names(etas) <- grpNames }
 	return(etas)
@@ -869,4 +877,14 @@ sample_etas_and_base <- function(fit, samples, newdata){
   ans <- list(baseMat = basePars, 
               etas = etas)
   return(ans)
+}
+
+subtractOffset <- function(new_x, offset){
+  ncol_x <- ncol(new_x)
+  ncol_off <- ncol(offset)
+  if(ncol_x != ncol_off) stop('ncol(new_x) != ncol(offset)')
+  for(i in seq_along(ncol_x)){
+    new_x[,i] <- new_x[,i] - offset[1,i]
+  }
+  return(new_x)
 }
\ No newline at end of file
